@@ -15,10 +15,9 @@ def main():
 
     if args.component_name:
         component_root = Path(__file__).resolve().parents[0]
-        component_dir = os.path.join(component_root, args.component_name)
-        os.mkdir(component_dir)
+        os.mkdir(args.component_name)
         example_dir = component_root / 'example' / 'rainbond-python-demo.zip'
-        extract(str(example_dir), component_dir)
+        extract(str(example_dir), args.component_name)
         print(
             'Successfully created `{0}` component. Run command:\n$ cd {0}\n$ pip3 install -r requirements.txt\n$ python3 app.py'.format(args.component_name))
 
